﻿
----------------------------------------
-- Index
----------------------------------------
-- Variables
-- Getters
-- Frames
-- Background Frame
-- Small Frames
-- Functions
-- Options Frame
-- CheckButtons
-- Info Frame
-- Updates
-- Event Frames
-- Slash Commands
----------------------------------------


----------------------------------------
-- Variables
----------------------------------------

local addonName, addon = ...
local versionNr = GetAddOnMetadata(addonName, "Version") 

local _
local DefaultFrames = {}
local HiddenFrames = {}
local ShownFrames = {}
local debugMode = false -- disable debug options (personal use when fixing the addon)


local DEFAULT_TRACKOFFSET_WITH = 27
local DEFAULT_TRACKOFFSET_WITHOUT = 10
local DEFAULT_LOCKVERTEX_OFF = 0.5
local DEFAULT_LOCKVERTEX_ON = 0.8
local OPTIONS_TINYBTN_SIZE = 20

local DEFAULT_BG = {"Left", [[Interface\COMMON\ShadowOverlay-Left]]}
local DEFAULT_EDGEFILE = [[Interface/DialogFrame/UI-DialogBox-Border]]

local mainBGBack = DEFAULT_BG[2]
local mainEdgefile = nill

local updateTimer = 0
local iconOffsetX = 6
local iconOffsetY = -1

local BGTable = {{"None", nill}
				,{"Top", [[Interface\COMMON\ShadowOverlay-Top]]}
				,{"Right", [[Interface\COMMON\ShadowOverlay-Right]]}
				,{"Bottom", [[Interface\COMMON\ShadowOverlay-Bottom]]}
				,{"Left", [[Interface\COMMON\ShadowOverlay-Left]]}
				,{"Full Light", [[Interface\DialogFrame\UI-DialogBox-Background]]}
				--,{"Full Dark", [[Interface\DialogFrame\UI-DialogBox-Background-Dark]]}
				,{"Full Border", [[Interface\Glues\CHARACTERCREATE\UI-CHARACTERCREATE-BACKGROUND]]}
				--,[[Interface\Glues\CREDITS\CrystalSong1TGA8]]
				--,[[Interface\ACHIEVEMENTFRAME\UI-Achievement-StatsBackground]]
				--,{"Red Border", [[Interface\FullScreenTextures\LowHealth]]}
				--,{"Blue Border", [[Interface\FullScreenTextures\OutOfControl]]}
				--}
				}
				
local FontCheckBox = "GameFontWhite"
local FontTracker = "GameFontNormal"

local BGOptions = { }--, "Left Purple", "Dragon", "Border Red", "Border Blue"}
local ActiveBG = DEFAULT_BG

local IconFrames = {}
local TrackingFrames = {}

local FrameInfoTable = {
	{"BGS_HonorFrame"			--1
	, "Honor Points"
	, {bgFile = [[Interface\ICONS\INV_Misc_QuestionMark]],
		edgeFile = nill,
		tile = true,
		tileSize = 16, edgeSize = 0,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		}
	}
	,
	{"BGS_ConquestFrame"		--2
	, "Conquest Points"
	, {bgFile = [[Interface\ICONS\INV_Misc_QuestionMark]],
		edgeFile = nill,
		tile = true,
		tileSize = 16, edgeSize = 0,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		}
	}
	,
	{"BGS_KillsFrame"		--3
	, "Character Kills"
	, {bgFile = [[Interface\ICONS\INV_MISC_BONE_HUMANSKULL_02]],
		edgeFile = nill,
		tile = false,
		tileSize = 16 , edgeSize = 0 ,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		}
	}
	,
	{"AccBGS_KillsFrame"		--4
	, "Account Kills"
	, {bgFile = [[Interface\ICONS\warrior_skullbanner]],
		edgeFile = nill,
		tile = false,
		tileSize = 16 , edgeSize = 0 ,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		}
	}
	,
	{"BGS_AchFrame"		--5
	, "Achievement"
	, {bgFile = [[Interface\ICONS\INV_Misc_QuestionMark]],
		edgeFile = nill,
		tile = false,
		tileSize = 16 , edgeSize = 0 ,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		}
	}
	,
	{"BGS_HolidayFrame"		--6
	, "Call to Arms"
	, {bgFile = [[Interface\ICONS\INV_Misc_QuestionMark]],
		edgeFile = nill,
		tile = false,
		tileSize = 16 , edgeSize = 0 ,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		}
	}
	,
	{"BGS_ScoreFrame"		--7
	, "Battleground Stats"
	, {bgFile = [[Interface\ICONS\INV_Misc_QuestionMark]],
		edgeFile = nill,
		tile = false,
		tileSize = 16 , edgeSize = 0 ,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		}
	}
	,
	{"BGS_TBFrame"		--8
	, "Tol Barad"
	, {bgFile = [[Interface\ICONS\Achievement_Zone_Tolbarad]],
		edgeFile = nill,
		tile = false,
		tileSize = 14  , edgeSize = 14  ,
		insets = { left = 0, right = 0, top = 0, bottom = 0}
		}
	}
	-- ,
	-- {"BGS_empty"		--8
	-- , "Empty"
	-- , {bgFile = [[Interface\ICONS\INV_Misc_QuestionMark]],
		-- edgeFile = nill,
		-- tile = false,
		-- tileSize = 14  , edgeSize = 14  ,
		-- insets = { left = 0, right = 0, top = 0, bottom = 0}
		-- }
	-- }
}



----------------------------------------
-- Getters
----------------------------------------

local function GetAccHKills()

-- Temp way of tracking account wide Hk. capped at 250k
local _, _, _, HKills, _, _, _, _, _, _ = GetAchievementCriteriaInfo(5363, 1)

--local HKills, _ = GetPVPLifetimeStats()
   return HKills
end

local function GetHKills()

   local HKills, _ = GetPVPLifetimeStats()
   return HKills
end

local function GetHonor()
   local _, CurrInfo, _, _, _, _ = GetCurrencyInfo(392)
   return CurrInfo
end

local function GetConquest()
   local _, CurrInfo, _, _, _, _ = GetCurrencyInfo(390)
   return CurrInfo
end

local function GetTB()
   local _, CurrInfo, _, _, _, _ = GetCurrencyInfo(391)
   return CurrInfo
end

local function GetBGHoliday()
	local _, bgName, _, bgWon, _, _, _, _, _ = GetHolidayBGInfo();
	if bgName ~= nil then
		return bgName
	end
	return "Unknown BG"
end

local function GetBGHolidayWon()
	local _, bgName, _, bgWon, _, _, _, _, _ = GetHolidayBGInfo();
	return bgWon
end



----------------------------------------
-- Frames
----------------------------------------

local function UpdateHolidayInfo()
local frameList = DefaultFrames[6]
local IconPath = [[InterFace\ICONS\Spell_Shadow_Twilight]];
local ShortStr = "" .. GetBGHoliday()

if ShortStr == "Warsong Gulch" then
   ShortStr = "WSG"
   IconPath = [[Interface\ICONS\INV_Misc_Rune_07]]
elseif ShortStr == "Arathi Basin" then
   ShortStr = "AB"
   IconPath = [[Interface\ICONS\INV_Jewelry_Amulet_07]]
elseif ShortStr == "Alterac Valley" then
   ShortStr = "AV"
   IconPath = [[Interface\ICONS\INV_Jewelry_Necklace_21]]
elseif ShortStr == "Eye of the Storm" then
   ShortStr = "EotS"
   IconPath = [[Interface\ICONS\Spell_Nature_EyeOfTheStorm]]
elseif ShortStr == "Strand of the Ancients" then
   ShortStr = "SotA"
   IconPath = [[Interface\ICONS\Achievement_BG_winSOA]]
elseif ShortStr == "Isle of Conquest" then
   ShortStr = "IoC"
   IconPath = [[Interface\ICONS\Achievement_BG_winWSG]]
elseif ShortStr == "The Battle for Gilneas" then
   ShortStr = "BfG"
   IconPath = [[Interface\ICONS\Achievement_Battleground_BattleForGilneas]]
elseif ShortStr == "Twin Peaks" then
   ShortStr = "Twin Peaks"
   IconPath = [[Interface\ICONS\Spell_Nature_EarthShock]]
elseif ShortStr == "Silvershard Mines" then
   ShortStr = "Silv. Mines"
   IconPath = [[Interface\ICONS\INV_Crate_07]]
elseif ShortStr == "Temple of Kotmogu" then
   ShortStr = "Temp. of K."
   IconPath = [[Interface\ICONS\Achievement_Battleground_TempleOfKotmogu_02]]
elseif ShortStr == "Deepwind Gorge" then
   ShortStr = "Deepw. G."
   IconPath = [[Interface\ICONS\achievement_zone_valleyoffourwinds]]
else
	ShortStr = "Unknown BG"
end

frameList[1].text:SetText(ShortStr)

IconFrames[6]:SetBackdrop({
      bgFile =  IconPath,
      edgeFile = nill,
      tile = false,
      tileSize = 16 , edgeSize = 0  ,
         insets = { left = 0, right = 0, top = 0 , bottom = 0}
})

   
end


local function SetShowMainframe(show) 
	if show then
		IsShown = true
		BGStatFrame:Show()
		BGS_VisibleButton.tex:SetTexture("Interface\\LFGFRAME\\BattlenetWorking9")
	else
		IsShown = false
		BGStatFrame:Hide()
		BGS_VisibleButton.tex:SetTexture("Interface\\LFGFRAME\\BattlenetWorking4")
	end
end

----------------------------------------
-- Background Frame
----------------------------------------

local L_BGStatFrame = CreateFrame("frame", "BGStatFrame", UIParent)
local function UpdateMainFrameBG()
	if BGStatFrame:IsMouseEnabled() then
		mainEdgefile = DEFAULT_EDGEFILE
	else
		mainEdgefile = nill
	end
	BGStatFrame:SetBackdrop({bgFile = mainBGBack,
      edgeFile = mainEdgefile,
	  tileSize = 0, edgeSize = 16,
      insets = { left = 3, right = 3, top = 3, bottom = 3 }
	  })
end
	 UpdateMainFrameBG()
BGStatFrame:SetWidth(107)
BGStatFrame:SetHeight(300)
BGStatFrame:SetMovable(true)
BGStatFrame:SetPoint("Center", 200, 0)
BGStatFrame:RegisterForDrag("LeftButton")
BGStatFrame:SetScript("OnDragStart", BGStatFrame.StartMoving )
BGStatFrame:SetScript("OnDragStop", BGStatFrame.StopMovingOrSizing)

BGStatFrame:SetClampedToScreen(true)
BGStatFrame:Show()

local function ToggleLockbutton() 
	if BGStatFrame:IsMouseEnabled() then
		BGS_MoveButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF )
		PlaySound("igMainMenuOptionCheckBoxOff");
		BGStatFrame:EnableMouse(false)
		BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF )
			
	else	
		BGS_MoveButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON )
		PlaySound("igMainMenuOptionCheckBoxOn");
		BGStatFrame:EnableMouse(true)
		BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON )
			
	end
		UpdateMainFrameBG()
end
------------------------------------------------------------------------------------------------------------------------
local L_FrameTitle = CreateFrame("Frame", "BGS_FrameTitle", BGStatFrame)
BGS_FrameTitle:SetPoint("top", BGStatFrame, "top", 0, 0)
BGS_FrameTitle:SetWidth(BGStatFrame:GetWidth())
BGS_FrameTitle:SetHeight(33)
BGS_FrameTitle:Show()

local L_Icon = CreateFrame("Frame", "BGS_Icon", BGS_FrameTitle)
BGS_Icon:SetWidth(24)
BGS_Icon:SetHeight(24)
local function FactionIcon()
   local EnglishFaction, localizedFaction = UnitFactionGroup("player")
   if EnglishFaction == "Horde" then
      BGS_Icon:SetBackdrop({
            bgFile = [[Interface\PVPFrame\PVP-Currency-Horde]],
            edgeFile = nil,
            tileSize = 32, edgeSize = 0,
      })
   else
      BGS_Icon:SetBackdrop({
            bgFile = [[Interface\PVPFrame\PVP-Currency-Alliance]],
            edgeFile = nil,
            tileSize = 32, edgeSize = 0,
      })
   end
end
FactionIcon()
BGS_Icon:SetPoint("topleft", BGS_FrameTitle, "topleft", 0, -2)
BGS_Icon.text = BGS_Icon:CreateFontString(nil, nil, "QuestFont_Shadow_Small")
BGS_Icon.text:SetPoint("left", 25, 0)
BGS_Icon.text:SetText("BG Stats")
BGS_Icon:Show()

------------------------------------------------------------------------------------------------------------------------

local L_BGS_CloseButton = CreateFrame("Button", "BGS_CloseButton", BGS_FrameTitle)
BGS_CloseButton:SetWidth(16)
BGS_CloseButton:SetHeight(16)
BGS_CloseButton:SetHitRectInsets(4, 4, 4, 4)
BGS_CloseButton:SetNormalTexture("Interface\\BUTTONS\\UI-Panel-MinimizeButton-Up")
BGS_CloseButton:SetHighlightTexture("Interface\\BUTTONS\\UI-Panel-MinimizeButton-Highlight")
BGS_CloseButton:SetPushedTexture("Interface\\BUTTONS\\UI-Panel-MinimizeButton-Down")
BGS_CloseButton:SetPoint("topright", BGS_FrameTitle, "topright", 0, -1)
BGS_CloseButton:Show()
BGS_CloseButton:SetScript("OnClick",  function() 
      PlaySound("igQuestLogClose");
	  SetShowMainframe(false) 
      
end)

------------------------------------------------------------------------------------------------------------------------

local L_BGS_ConfigButton = CreateFrame("Button", "BGS_ConfigButton", BGS_FrameTitle)
BGS_ConfigButton:SetWidth(8)
BGS_ConfigButton:SetHeight(8)
BGS_ConfigButton:SetNormalTexture("Interface\\BUTTONS\\UI-GuildButton-PublicNote-Up")
BGS_ConfigButton:SetHighlightTexture("Interface\\BUTTONS\\UI-GuildButton-PublicNote-Up")
BGS_ConfigButton:SetPushedTexture("Interface\\BUTTONS\\UI-GuildButton-OfficerNote-Up")
BGS_ConfigButton:SetPoint("topright", BGS_FrameTitle, "topright", -4, -15)
BGS_ConfigButton:Show()
BGS_ConfigButton:SetScript("OnClick",  function() 
	if ( not InterfaceOptionsFramePanelContainer.displayedPanel ) then
		InterfaceOptionsFrame_OpenToCategory(CONTROLS_LABEL);
	end
	InterfaceOptionsFrame_OpenToCategory(addonName)
	
end)

------------------------------------------------------------------------------------------------------------------------

local L_BGS_MoveButton = CreateFrame("Button", "BGS_MoveButton", BGS_FrameTitle)
BGS_MoveButton:SetWidth(8)
BGS_MoveButton:SetHeight(8)
BGS_MoveButton.tex = BGS_MoveButton:CreateTexture("BGS_MoveButton_Tex")
BGS_MoveButton.tex:SetTexture("Interface\\COMMON\\UI-ModelControlPanel")
BGS_MoveButton.tex:SetPoint("topright", BGS_FrameTitle, "topright", -13, -15)
BGS_MoveButton.tex:SetTexCoord(18/64, 36/64, 37/128, 53/128)
BGS_MoveButton.tex:SetSize(8,8)
BGS_MoveButton.tex:SetVertexColor(.8, .8, .8 ) 

BGS_MoveButton:SetPoint("topright", BGS_FrameTitle, "topright", -13, -15)
BGS_MoveButton:Show()

BGS_MoveButton:SetScript("OnClick",  function() 
	ToggleLockbutton()
	
end)
BGS_MoveButton:SetScript("OnEnter",  function() 
	BGS_MoveButton.tex:SetVertexColor(1, 1, 1 )
	
end)
BGS_MoveButton:SetScript("OnLeave",  function() 
	if BGStatFrame:IsMouseEnabled() then
		BGS_MoveButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON )
	else	
		BGS_MoveButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF )
	end
	
end)

----------------------------------------
-- Small Frames
----------------------------------------
for k, v in ipairs(FrameInfoTable) do
	local frame = CreateFrame("frame", v[1], BGStatFrame)
	frame.text = frame:CreateFontString(nil, nil, "GameFontNormal")
	frame.text:SetPoint("left", DEFAULT_TRACKOFFSET_WITH, 0)
	frame:SetPoint("topleft", BGStatFrame, "topleft", 0, -25)
	frame:SetWidth(BGStatFrame:GetWidth())
	frame:SetHeight(20)
	frame:Hide()
	table.insert(DefaultFrames, k, {frame, v[2]})
	
	local iconName = v[1] .. "Icon"
	local icon = CreateFrame("frame", iconName, frame)
	icon:SetWidth(frame:GetHeight()-2)
	icon:SetHeight(frame:GetHeight()-2)
	icon:SetPoint("left", frame, "left", iconOffsetX, iconOffsetY)
	icon:SetBackdrop(v[3])
	icon:Show()
	table.insert(IconFrames, k, icon)
	
end

local function UpdateHonorInfo()
	local frameList = DefaultFrames[1]
	frameList[1].text:SetText(GetHonor())
end
UpdateHonorInfo()

local function HonorIcon()
	local EnglishFaction, localizedFaction = UnitFactionGroup("player")
	local bg = nill
	if EnglishFaction == "Horde" then
		bg = [[Interface\ICONS\PVPCurrency-Honor-Horde]]
	else
        bg = [[Interface\ICONS\PVPCurrency-Honor-Alliance]]
	end
	IconFrames[1]:SetBackdrop({
			bgFile = bg,
            edgeFile = nill,
            tile = true,
            tileSize = 16, edgeSize = 0,
            insets = { left = 0, right = 0, top = 0, bottom = 0 }
		})
end
HonorIcon()
------------------------------------------------------------------------------------------------------------------------

local function UpdateConquestInfo()
	local frameList = DefaultFrames[2]
	frameList[1].text:SetText(GetConquest())
end
UpdateConquestInfo()

local function ConquestIcon()
   local EnglishFaction, localizedFaction = UnitFactionGroup("player")
   local bg = nill
   if EnglishFaction == "Horde" then
        bg = [[Interface\ICONS\PVPCurrency-Conquest-Horde]]
   else
        bg = [[Interface\ICONS\PVPCurrency-Conquest-Alliance]]
	end
	IconFrames[2]:SetBackdrop({
            bgFile = bg,
            edgeFile = nill,
            tile = false,
            tileSize = 16, edgeSize = 0,
            insets = { left = 0, right = 0, top = 0, bottom = 0 }
		})
end
ConquestIcon()

------------------------------------------------------------------------------------------------------------------------
local function UpdateKillsInfo()
	local frameList = DefaultFrames[3]
	frameList[1].text:SetText(GetHKills())
end

------------------------------------------------------------------------------------------------------------------------

local function UpdateAccKillsInfo()
	local frameList = DefaultFrames[4]
	frameList[1].text:SetText(GetAccHKills())
end


------------------------------------------------------------------------------------------------------------------------

local function UpdateAchInfo()
	local frameList = DefaultFrames[5]
	
	local HKills = GetAccHKills()
	local AchRankPath = [[]]
	local KillsLeft = 0
	if HKills < 1 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_01]]
		KillsLeft = 1 - HKills
	elseif 1 <= HKills and HKills < 100 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_02]]
		KillsLeft = 100 - HKills
	elseif 100 <= HKills and HKills < 500 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_03]]
		KillsLeft = 500 - HKills
	elseif 500 <= HKills and HKills < 1000 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_04]]
		KillsLeft = 1000 - HKills
	elseif 1000 <= HKills and HKills < 5000 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_06]]
		KillsLeft = 5000 - HKills
	elseif 5000 <= HKills and HKills < 10000 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_09]]
		KillsLeft = 10000 - HKills
	elseif 10000 <= HKills and HKills < 25000 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_11]]
		KillsLeft = 25000 - HKills
	elseif 25000 <= HKills and HKills < 50000 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_14]]
		KillsLeft = 50000 - HKills
	elseif 50000 <= HKills and HKills < 100000 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_15]]
		KillsLeft = 100000 - HKills
	elseif 100000 <= HKills and HKills < 250000 then
		AchRankPath = [[Interface\ICONS\Achievement_PVP_P_16]]
		KillsLeft = 250000 - HKills
	elseif 250000 <= HKills then
		AchRankPath = [[Interface\ICONS\Achievement_BG_KillFlagCarriers_grabFlag_CapIt]]
		KillsLeft = "Max Rank"
	end
	IconFrames[5]:SetBackdrop({
		bgFile = AchRankPath,
		edgeFile = nill,
		tile = false,
		tileSize = 16  , edgeSize = 0  ,
		insets = { left = 0, right = 0, top = 0 , bottom = 0}
   })
   
   frameList[1].text:SetText(KillsLeft)
   
end


------------------------------------------------------------------------------------------------------------------------
local function UpdateBGScoreInfo()
	local frameList = DefaultFrames[7]
	
	local isInstance, instanceType = IsInInstance()
	if instanceType == "pvp" then
		RequestBattlefieldScoreData()
		for i = 1, GetNumBattlefieldScores() do
			local name, killingBlows, honorableKills, deaths, honorGained, faction, race, class, classToken, damageDone, healingDone = GetBattlefieldScore(i)
			if name == GetUnitName("player", false) then
				frameList[1].text:SetText("" .. honorableKills .. "(" .. killingBlows .. ") / " .. deaths)
				return --no need to count more
			end
		end
	else
		frameList[1].text:SetText("Not in a BG")
	end
end

local function BGScoreIcon()
   local EnglishFaction, localizedFaction = UnitFactionGroup("player")
   local bg = nill
   if EnglishFaction == "Horde" then
		bg = [[Interface\ICONS\Achievement_PVP_H_H]]
   else
		bg = [[Interface\ICONS\Achievement_PVP_A_A]]
   end
	IconFrames[7]:SetBackdrop({
            bgFile = bg,
            edgeFile = nill,
            tile = false,
            tileSize = 14, edgeSize = 14,
            insets = { left = 0, right = 0, top = 0, bottom = 0 }
      })
end
BGScoreIcon()


------------------------------------------------------------------------------------------------------------------------
local function UpdateTBInfo()
	local frameList = DefaultFrames[8]
	frameList[1].text:SetText(GetTB())
end
UpdateTBInfo()



----------------------------------------
-- Functions
----------------------------------------

local function ChangeBG(bgList)
	if type(bgList) == type(1) or (not bgList) then --for old versions
		ActiveBG = BGTable[5]
	else
		ActiveBG = bgList
	end
	mainBGBack = ActiveBG[2]
	UpdateMainFrameBG()
	UIDropDownMenu_SetText(BGS_BGDropDown, ""..ActiveBG[1])
end

------------------------------------------------------------------------------------------------------------------------

local function TrackFramePos()
	local spacing = -6
	if BGS_FrameTitle:IsShown() then
		spacing = spacing - 20
	end
	for  id, frame in ipairs(ShownFrames) do
		local TempFrame = frame[1]
		TempFrame:SetPoint("topleft", BGStatFrame, "topleft", 0, spacing)
		spacing = spacing - TempFrame:GetHeight()
		TempFrame:Show()
	end
end
------------------------------------------------------------------------------------------------------------------------

local function FrameHeights()
	local spacing = -25
	for  id, list in ipairs(ShownFrames) do
		local TempFrame = list[1]
		TempFrame:SetPoint("topleft", BGStatFrame, "topleft", 0, spacing)
		spacing = spacing - TempFrame:GetHeight()
		TempFrame:Show()
	end
end

local function ResizeBG()
	local BGSize = 14
	if BGS_FrameTitle:IsShown() then
		BGSize = BGSize + 19
	end
	for  id, frame in ipairs(ShownFrames) do
		BGSize = BGSize + frame[1]:GetHeight()
	end
	BGStatFrame:SetHeight(BGSize)
	return true
end

ResizeBG()

------------------------------------------------------------------------------------------------------------------------

local function DoShowFrames()
	for k, v in ipairs(ShownFrames) do
		v[1]:Show()
	end
end

local function DoHiddenFrames()
	for k, v in ipairs(HiddenFrames) do
		v[1]:Hide()
	end
end

local function PlaceHiddenFrameOptions()
	local ypos = 5
	local step = 21
	for k1, v1 in ipairs(DefaultFrames) do -- hidden compare to default to keep the same order
		for k2, v2 in ipairs(HiddenFrames) do	
			if v1 == v2 then
				local _, _, move = v2[3]:GetChildren()
				move:SetNormalTexture("Interface\\BUTTONS\\UI-SpellbookIcon-NextPage-Up")
				move:SetHighlightTexture("Interface\\BUTTONS\\UI-SpellbookIcon-NextPage-Down")
				move:SetPushedTexture("Interface\\BUTTONS\\UI-SpellbookIcon-NextPage-Down")
				v2[3]:SetParent(BGS_FramesortBG_Left)
				v2[3]:SetPoint("topleft", v2[3]:GetParent(), "topleft", 5, -ypos)
				v2[3]:SetWidth(v2[3]:GetParent():GetWidth()-10)
				ypos = ypos + step
			end
		end
	end
end

local function PlaceShownFrameOptions()
	local ypos = 5
	local step = 21
		for k, v in ipairs(ShownFrames) do	
			local btnUp, btnDown, move = v[3]:GetChildren()
			move:SetNormalTexture("Interface\\BUTTONS\\UI-SpellbookIcon-PrevPage-Up")
			move:SetHighlightTexture("Interface\\BUTTONS\\UI-SpellbookIcon-PrevPage-Down")
			move:SetPushedTexture("Interface\\BUTTONS\\UI-SpellbookIcon-PrevPage-Down")
			btnUp:Show()
			btnDown:Show()
			v[3]:SetParent(BGS_FramesortBG_Right)
			v[3]:SetPoint("topleft", v[3]:GetParent(), "topleft", 5, -ypos)
			v[3]:SetWidth(v[3]:GetParent():GetWidth()-10)
			ypos = ypos + step
			if k == 1 then
				btnUp:Hide()
			elseif k == table.getn(ShownFrames) then
				btnDown:Hide()
			end
		end
end

BGS_HolidayFrame:SetScript("OnUpdate", function(self,elapsed) 
	updateTimer = updateTimer + elapsed
	if updateTimer >= 60*30 then
		UpdateHolidayInfo()
		updateTimer = 0
	end
	end)


local function ShowFrame(key)
	local list = DefaultFrames[key]
	table.insert(ShownFrames, list)
	for k, v in ipairs(HiddenFrames) do
		if v == list then
			table.remove(HiddenFrames, k)
		end
	end
end

local function HideFrame(key)
	local list = DefaultFrames[key]
	table.insert(HiddenFrames, list)
	for k, v in ipairs(ShownFrames) do
		if v == list then
			table.remove(ShownFrames, k)
		end
	end
end

local function GetPositionInDefault(id)
	for k, v in ipairs(DefaultFrames) do	
		if v == id then
			return k
		end
	end
	return -1
end

local function GetPositionInDefaultName(s)
	for k, v in ipairs(DefaultFrames) do	
		if v[2] == s then
			return k
		end
	end
	return -1
end

local function GetPositionInShown(key)
	for k, v in ipairs(ShownFrames) do	
		if v == DefaultFrames[key] then
			return k
		end
	end
	return 0
end

local function MoveUpInShown(key)
	local id = GetPositionInShown(key)
	if id > 1 then
		local temp = ShownFrames[id-1]
		ShownFrames[id-1] = ShownFrames[id]
		ShownFrames[id] = temp
	end
end

local function MoveDownInShown(key)
	local id = GetPositionInShown(key)
	if id < table.getn(ShownFrames) then
		local temp = ShownFrames[id+1]
		ShownFrames[id+1] = ShownFrames[id]
		ShownFrames[id] = temp
	end
end

local function FixOptionFrames()
	DoShowFrames()
	DoHiddenFrames()
	PlaceHiddenFrameOptions()
	PlaceShownFrameOptions()
	TrackFramePos()
	ResizeBG()
end

----------------------------------------
-- Options Frame
----------------------------------------
local ypos = 16
local step = 20

local L_BGS_Option = CreateFrame("Frame", "BGS_Option", InterfaceOptionsFramePanelContainer)
L_BGS_Option:SetScript("OnShow",  function() 
		
		
	end)
BGS_Option:Hide()
BGS_Option.name = addonName
local BGS_Option_Title = BGS_Option:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
BGS_Option_Title:SetPoint("TOPLEFT", 16, -ypos)
BGS_Option_Title:SetText(addonName .. " v" .. versionNr)



local L_BGS_LockButton = CreateFrame("Button", "BGS_LockButton", BGS_Option)
BGS_LockButton:SetWidth(16)
BGS_LockButton:SetHeight(16)
BGS_LockButton:SetPoint("TOPLEFT", BGS_Option, "TOPLEFT", 140, -ypos)
BGS_LockButton.text = BGS_LockButton:CreateFontString(nil, nil, "GameFontNormal")
BGS_LockButton.text:SetPoint("top", 0, -3)
--BGS_LockButton.text:SetText("Enabled")
BGS_LockButton:Show()
BGS_LockButton:SetScript("ONCLICK", ToggleLockbutton)

BGS_LockButton.tex = BGS_LockButton:CreateTexture("BGS_LockButton_Tex")
BGS_LockButton.tex:SetTexture("Interface\\COMMON\\UI-ModelControlPanel")
BGS_LockButton.tex:SetPoint("center", BGS_LockButton, "center", 0, 0)
BGS_LockButton.tex:SetTexCoord(18/64, 36/64, 37/128, 53/128)
BGS_LockButton.tex:SetSize(17,17)
BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON ) 
BGS_LockButton:SetScript("OnEnter",  function() 
	BGS_LockButton.tex:SetVertexColor(1, 1, 1 )
	Text_OptionInfo.text:SetText("Enable/disable frame movement")
end)
BGS_LockButton:SetScript("OnLeave",  function() 
	if BGStatFrame:IsMouseEnabled() then
		BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON )
	else	
		BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF )
	end
	Text_OptionInfo.text:SetText("")
end)


local L_BGS_VisibleButton = CreateFrame("Button", "BGS_VisibleButton", BGS_Option)
BGS_VisibleButton:SetWidth(16)
BGS_VisibleButton:SetHeight(16)
BGS_VisibleButton:SetPoint("TOPLEFT", BGS_Option, "TOPLEFT", 160, -ypos)
BGS_VisibleButton.text = BGS_VisibleButton:CreateFontString(nil, nil, "GameFontNormal")
BGS_VisibleButton.text:SetPoint("top", 0, -3)
--BGS_LockButton.text:SetText("Enabled")
BGS_VisibleButton:Show()
BGS_VisibleButton:SetScript("ONCLICK", function() SetShowMainframe((not BGStatFrame:IsShown())) end)

BGS_VisibleButton.tex = BGS_VisibleButton:CreateTexture("BGS_VisibleButton_Tex")
BGS_VisibleButton.tex:SetTexture("Interface\\LFGFRAME\\BattlenetWorking9")
BGS_VisibleButton.tex:SetPoint("center", BGS_VisibleButton, "center", 0, 0)
BGS_VisibleButton.tex:SetSize(25,25)
BGS_VisibleButton:SetScript("OnEnter",  function() 
	BGS_VisibleButton.tex:SetTexture("Interface\\LFGFRAME\\BattlenetWorking2")
	Text_OptionInfo.text:SetText("Show/hide tracking frame.")
	
end)
BGS_VisibleButton:SetScript("OnLeave",  function() 
	if BGStatFrame:IsShown() then
		BGS_VisibleButton.tex:SetTexture("Interface\\LFGFRAME\\BattlenetWorking9")
	else	
		BGS_VisibleButton.tex:SetTexture("Interface\\LFGFRAME\\BattlenetWorking4")
	end
	Text_OptionInfo.text:SetText("")
end)

local L_Text_OptionInfo = CreateFrame("FRAME", "Text_OptionInfo", BGS_Option)

Text_OptionInfo:SetHeight(15);
Text_OptionInfo:SetWidth(100);
Text_OptionInfo:SetPoint("topleft", BGS_Option, "topleft", 200, -ypos)
Text_OptionInfo.text = Text_OptionInfo:CreateFontString(nil, nil, FontCheckBox)
Text_OptionInfo.text:SetPoint("left", 0, 0)
Text_OptionInfo.text:SetText("")

Text_OptionInfo:Show()
------------------------------------------------------------------------------------------------------------------------
ypos = ypos + step + 5

--local BGS_Txt_lock = CreateFrame("FRAME", "BGS_Txt_lock", BGS_Option)
--BGS_Txt_lock.text = BGS_Txt_lock:CreateFontString(nil, nil, FontCheckBox)
--BGS_Txt_lock.text:SetPoint("left", 0, 0)
--BGS_Txt_lock.text:SetText("Allow the frame to move: ")
--BGS_Txt_lock:SetHeight(BGS_Txt_lock.text:GetHeight());
--BGS_Txt_lock:SetWidth(BGS_Txt_lock.text:GetWidth());
--BGS_Txt_lock:SetPoint("topleft", BGS_Option, "topleft", 16, -ypos-1)
--BGS_Txt_lock:Show()



------------------------------------------------------------------------------------------------------------------------

--ypos = ypos + step +10

local L_BGS_Txt_ListInfo = CreateFrame("FRAME", "BGS_Txt_ListInfo", BGS_Option)
BGS_Txt_ListInfo.text = BGS_Txt_ListInfo:CreateFontString(nil, nil, "GameFontHighlightSmall")
BGS_Txt_ListInfo.text:SetPoint("left", 0, 0)
BGS_Txt_ListInfo.text:SetText("You can hide or show the different frames by moving them between lists using the buttons")
BGS_Txt_ListInfo:SetHeight(15);
BGS_Txt_ListInfo:SetWidth(100);
BGS_Txt_ListInfo:SetPoint("topleft", BGS_Option, "topleft", 16, -ypos)
BGS_Txt_ListInfo:Show()

local L_BGS_Txt_ListInfo2 = CreateFrame("FRAME", "BGS_Txt_ListInfo2", BGS_Option)
BGS_Txt_ListInfo2.text = BGS_Txt_ListInfo2:CreateFontString(nil, nil, "GameFontHighlightSmall")
BGS_Txt_ListInfo2.text:SetPoint("left", 0, 0)
BGS_Txt_ListInfo2.text:SetText(" You can also change the order of the visible frames.")
BGS_Txt_ListInfo2:SetHeight(15);
BGS_Txt_ListInfo2:SetWidth(100);
BGS_Txt_ListInfo2:SetPoint("topleft", BGS_Option, "topleft", 16, -ypos-10)
BGS_Txt_ListInfo2:Show()

----------------------------------------
-- CheckButtons
----------------------------------------
local cbStep = 20;
local cbypos = 30
local optionframeWidth = 182
ypos = ypos + step + step + 5

local L_BGS_FramesortBG_Left = CreateFrame("frame", "BGS_FramesortBG_Left", BGS_Option)
BGS_FramesortBG_Left:SetPoint("topleft", BGS_Option, "topleft", 20, -ypos)
BGS_FramesortBG_Left:SetBackdrop({bgFile = [[Interface\BlackMarket\BlackMarketBackground-Tile]],
      edgeFile = DEFAULT_EDGEFILE, tile = true,
	  tileSize = 300, edgeSize = 16,
      insets = { left = 3, right = 3, top = 3, bottom = 3 }
	  })
BGS_FramesortBG_Left:SetWidth(150)
BGS_FramesortBG_Left:SetHeight(175)
BGS_FramesortBG_Left.label = BGS_FramesortBG_Left:CreateTexture("BGS_MoveButton_Tex")
BGS_FramesortBG_Left.label:SetTexture("Interface\\COMMON\\Common-Input-Border")
-- BGS_FramesortBG_Left.label:SetTexture("Interface\\EncounterJournal\\UI-ENCOUNTERJOURNALTEXTURES")
BGS_FramesortBG_Left.label:SetTexCoord(0, 1, 0, 0.5)

BGS_FramesortBG_Left.label:SetPoint("top", BGS_FramesortBG_Left, "top", 0, 15)

--BGS_FramesortBG_Left.label:SetVertexColor(.8, .8, .8 ) 
BGS_FramesortBG_Left.text = BGS_FramesortBG_Left:CreateFontString(nil, nil, "GameFontNormal")
BGS_FramesortBG_Left.text:SetPoint("top", 0, 12)
BGS_FramesortBG_Left.text:SetText("Hidden Frames") 
BGS_FramesortBG_Left.label:SetSize(BGS_FramesortBG_Left:GetWidth()-20, 18)

local function ChangeFremsortHeights()
	local step = 21
	local size = 10 + table.getn(DefaultFrames) * step
	BGS_FramesortBG_Left:SetHeight(size)
end
ChangeFremsortHeights()

local L_BGS_FramesortBG_Right = CreateFrame("frame", "BGS_FramesortBG_Right", BGS_Option)
BGS_FramesortBG_Right:SetPoint("topleft", BGS_Option, "topleft", 180, -ypos)
BGS_FramesortBG_Right:SetBackdrop({bgFile = [[Interface\BlackMarket\BlackMarketBackground-Tile]],
      edgeFile = DEFAULT_EDGEFILE, tile = true,
	  tileSize = 200, edgeSize = 16,
      insets = { left = 3, right = 3, top = 3, bottom = 3 }
	  })
BGS_FramesortBG_Right:SetWidth(optionframeWidth)
BGS_FramesortBG_Right:SetHeight(BGS_FramesortBG_Left:GetHeight())
BGS_FramesortBG_Right.label = BGS_FramesortBG_Right:CreateTexture("BGS_MoveButton_Tex")
BGS_FramesortBG_Right.label:SetTexture("Interface\\COMMON\\Common-Input-Border")
-- BGS_FramesortBG_Right.label:SetTexture("Interface\\EncounterJournal\\UI-ENCOUNTERJOURNALTEXTURES")
BGS_FramesortBG_Right.label:SetTexCoord(0, 1, 0, 0.5)
BGS_FramesortBG_Right.label:SetPoint("top", BGS_FramesortBG_Right, "top", 0, 15)
BGS_FramesortBG_Right.text = BGS_FramesortBG_Right:CreateFontString(nil, nil, "GameFontNormal")
BGS_FramesortBG_Right.text:SetPoint("top", 0, 12)
BGS_FramesortBG_Right.text:SetText("Visible Frames")
BGS_FramesortBG_Right.label:SetSize(BGS_FramesortBG_Right:GetWidth()-20, 18)


local smally = 0
local smallStep = 21
for k,v in  ipairs(DefaultFrames) do
	local trackName = v[2]
	local trackFrame = v[1]

	local BGS_OptframeDefault = CreateFrame("frame", "BGS__OptframeDefault", BGS_FramesortBG_Left)
	BGS_OptframeDefault:SetPoint("topleft", BGS_OptframeDefault:GetParent(), "topleft", 5, -smally)
	BGS_OptframeDefault:SetBackdrop({bgFile = [[Interface\CHATFRAME\ChatFrameTab-BGMid-min]],
		edgeFile = nil, 
		tileSize = 0, edgeSize = 16,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
		})
	BGS_OptframeDefault:SetWidth(BGS_OptframeDefault:GetParent():GetWidth()-10)
	BGS_OptframeDefault:SetHeight(20)
	BGS_OptframeDefault.text = BGS_OptframeDefault:CreateFontString(nil, nil, "GameFontNormal")
	BGS_OptframeDefault.text:SetPoint("left", 5, 0)
	BGS_OptframeDefault.text:SetText(trackName)

	table.insert(v, BGS_OptframeDefault)

	local moveUp = CreateFrame("Button", "BGS_OptframeDefault_moveUp", BGS_OptframeDefault)
	moveUp:SetWidth(OPTIONS_TINYBTN_SIZE)
	moveUp:SetHeight(OPTIONS_TINYBTN_SIZE)
	moveUp:SetNormalTexture("Interface\\CHATFRAME\\UI-ChatIcon-ScrollUp-Up")
	moveUp:SetHighlightTexture("Interface\\CHATFRAME\\UI-ChatIcon-ScrollUp-Down")
	moveUp:SetPushedTexture("Interface\\CHATFRAME\\UI-ChatIcon-ScrollUp-Down")
	moveUp:SetPoint("left", BGS_OptframeDefault, "left", 122 +(15+1)*1, 0)
	moveUp:SetScript("OnClick",  function(self)
	PlaySound("igMainMenuOptionCheckBoxOn");
	MoveUpInShown(k)
	FixOptionFrames()
end)
moveUp:Hide()

local moveDown = CreateFrame("Button", "BGS_OptframeDefault_moveDown", BGS_OptframeDefault)
moveDown:SetWidth(OPTIONS_TINYBTN_SIZE)
moveDown:SetHeight(OPTIONS_TINYBTN_SIZE)
moveDown:SetNormalTexture("Interface\\CHATFRAME\\UI-ChatIcon-ScrollDown-Up")
moveDown:SetHighlightTexture("Interface\\CHATFRAME\\UI-ChatIcon-ScrollDown-Down")
moveDown:SetPushedTexture("Interface\\CHATFRAME\\UI-ChatIcon-ScrollDown-Down")
moveDown:SetPoint("left", BGS_OptframeDefault, "left", 122 +(15+1)*2, 0)
moveDown:SetScript("OnClick",  function(self)
	PlaySound("igMainMenuOptionCheckBoxOn");
	MoveDownInShown(k)
	FixOptionFrames()
end)
moveDown:Hide()

local move = CreateFrame("Button", "BGS_OptframeDefault_move", BGS_OptframeDefault)
move:SetWidth(OPTIONS_TINYBTN_SIZE)
move:SetHeight(OPTIONS_TINYBTN_SIZE)
move:SetNormalTexture("Interface\\BUTTONS\\UI-SpellbookIcon-NextPage-Up")
move:SetHighlightTexture("Interface\\BUTTONS\\UI-SpellbookIcon-NextPage-Down")
move:SetPushedTexture("Interface\\BUTTONS\\UI-SpellbookIcon-NextPage-Down")
move:SetPoint("left", BGS_OptframeDefault, "left", 122, 0)
move:Show()
move:SetScript("OnClick",  function(self)
	PlaySound("igMainMenuOptionCheckBoxOn");
	local parent = self:GetParent()
	local btnUp, btnDown = parent:GetChildren()
	--DEFAULT_CHAT_FRAME:AddMessage(c1:GetName() .." and " ..c2:GetName())
	if parent:GetParent():GetName() == "BGS_FramesortBG_Right" then
		parent:SetParent(BGS_FramesortBG_Left)
		HideFrame(k)
		btnUp:Hide()
		btnDown:Hide()
	else
		parent:SetParent(BGS_FramesortBG_Right)
		btnUp:Show()
		btnDown:Show()
		ShowFrame(k)
	end
	parent:SetPoint("topleft", v[3]:GetParent(), "topleft", 5, -5)
	parent:SetWidth(parent:GetParent():GetWidth()-10)
	FixOptionFrames()
	--self:Hide()
end)
smally = smally + smallStep
end

ypos = ypos + step + BGS_FramesortBG_Left:GetHeight()

local L_Text_OptionBG = CreateFrame("FRAME", "Text_OptionBG", BGS_Option)
Text_OptionBG.text = Text_OptionBG:CreateFontString(nil, nil, FontCheckBox)
Text_OptionBG.text:SetPoint("left", 0, 0)
Text_OptionBG.text:SetText("Change background")
Text_OptionBG:SetHeight(15);
Text_OptionBG:SetWidth(100);
Text_OptionBG:SetPoint("topleft", BGS_Option, "topleft", 15, -ypos -5)
Text_OptionBG:Show()

local function BGS_BGDD_Select(self, arg1, arg2, checked)
	UIDropDownMenu_SetText(BGS_BGDropDown, ""..self.value)
	ActiveBG = arg1
	ChangeBG(ActiveBG)
end

local function BGS_BGDD_Menu(frame, level, menuList)
	local info = UIDropDownMenu_CreateInfo()
	info.func = BGS_BGDD_Select
	for k, v in ipairs(BGTable) do 
		info.text, info.arg1 = v[1], v
		UIDropDownMenu_AddButton(info)
	end
end

local BGS_BGDropDown = CreateFrame("frame", "BGS_BGDropDown", BGS_Option, "UIDropDownMenuTemplate")
BGS_BGDropDown:SetPoint("topleft", BGS_Option, "topleft", 125, -ypos)
--BGS_BGDropDown.bg = BGS_BGDropDown:CreateTexture("BGS_BGDropDown_Tex")
--BGS_BGDropDown.bg:SetTexture("Interface\\COMMON\\Common-Input-Border")
--BGS_BGDropDown.bg:SetPoint("left", BGS_BGDropDown, "left", 25, -3)
--BGS_BGDropDown.bg:SetTexCoord(18/64, 36/64, 37/128, 53/128)
--BGS_BGDropDown.bg:SetSize(90,33)
--BGS_BGDropDown.bg:SetVertexColor(.8, .8, .8 ) 
--BGS_BGDropDown.arrow = BGS_BGDropDown:CreateTexture("BGS_BGDropDown_Arrow")
--BGS_BGDropDown.arrow:SetTexture("Interface\\Buttons\\Arrow-Down-Up")
--BGS_BGDropDown.arrow:SetPoint("left", BGS_BGDropDown, "left", 29, -2)
--BGS_BGDropDown.arrow:SetSize(16,16)

UIDropDownMenu_SetWidth(BGS_BGDropDown, 100)
UIDropDownMenu_SetText(BGS_BGDropDown, ActiveBG[1])
UIDropDownMenu_Initialize(BGS_BGDropDown, BGS_BGDD_Menu, "MENU") --Menu to bypass taint
BGS_BGDropDownLeft:Show()
BGS_BGDropDownMiddle:Show()
BGS_BGDropDownMiddle:SetWidth(100)
BGS_BGDropDownRight:Show()
BGS_BGDropDownButton:SetPoint("topright", BGS_BGDropDownRight, "topright", -16, -18)
BGS_BGDropDownButton:SetNormalTexture("Interface\\ChatFrame\\UI-ChatIcon-ScrollDown-Up")
BGS_BGDropDownButton:SetHighlightTexture("Interface\\Buttons\\UI-Common-MouseHilight")
BGS_BGDropDownButton:SetPushedTexture("Interface\\ChatFrame\\UI-ChatIcon-ScrollDown-Down")

ypos = ypos + step + step

local L_BGS_CBHideIcons = CreateFrame("checkbutton", "BGS_CBHideIcons", BGS_Option)
BGS_CBHideIcons:SetWidth(25)
BGS_CBHideIcons:SetHeight(25)
BGS_CBHideIcons:SetNormalTexture("Interface\\BUTTONS\\UI-CheckBox-Up")
BGS_CBHideIcons:SetHighlightTexture("Interface/BUTTONS/UI-CheckBox-Highlight")
BGS_CBHideIcons:SetPushedTexture("Interface\\BUTTONS\\UI-CheckBox-Down")
BGS_CBHideIcons:SetPoint("topleft", BGS_Option, "topleft", 15, -ypos)
BGS_CBHideIcons.text = BGS_CBHideIcons:CreateFontString(nil, nil, FontCheckBox)
BGS_CBHideIcons.text:SetPoint("left", 30, 0)
BGS_CBHideIcons.text:SetText("Show Icons")
BGS_CBHideIcons:SetCheckedTexture("Interface\\BUTTONS\\UI-CheckBox-Check")
BGS_CBHideIcons:SetScript("OnClick", function ()
	if  BGS_CBHideIcons:GetChecked() == 1 then
		PlaySound("igMainMenuOptionCheckBoxOn");
		for k, v in ipairs(DefaultFrames) do 
			v[1].text:SetPoint("left", DEFAULT_TRACKOFFSET_WITH, 0)
			v[1]:GetChildren():Show()
		end
		
        BGS_CBHideIcons:SetChecked(true)
	else
		PlaySound("igMainMenuOptionCheckBoxOff");
		for k, v in ipairs(DefaultFrames) do 
			v[1].text:SetPoint("left", DEFAULT_TRACKOFFSET_WITHOUT, 0)
			v[1]:GetChildren():Hide()
		end
		BGS_CBHideIcons:SetChecked(false)
	end
end)

ypos = ypos + step + step/2
 
local L_BGS_CBHideTitle = CreateFrame("checkbutton", "BGS_CBHideTitle", BGS_Option)
BGS_CBHideTitle:SetWidth(25)
BGS_CBHideTitle:SetHeight(25)
BGS_CBHideTitle:SetNormalTexture("Interface\\BUTTONS\\UI-CheckBox-Up")
BGS_CBHideTitle:SetHighlightTexture("Interface/BUTTONS/UI-CheckBox-Highlight")
BGS_CBHideTitle:SetPushedTexture("Interface\\BUTTONS\\UI-CheckBox-Down")
BGS_CBHideTitle:SetPoint("topleft", BGS_Option, "topleft", 15, -ypos)
BGS_CBHideTitle.text = BGS_CBHideTitle:CreateFontString(nil, nil, FontCheckBox)
BGS_CBHideTitle.text:SetPoint("left", 30, 0)
BGS_CBHideTitle.text:SetText("Show Title and buttons")
BGS_CBHideTitle:SetCheckedTexture("Interface\\BUTTONS\\UI-CheckBox-Check")
BGS_CBHideTitle:SetScript("OnClick", function ()
	local frame
	if  BGS_CBHideTitle:GetChecked() == 1 then
		PlaySound("igMainMenuOptionCheckBoxOn");
		BGS_FrameTitle:Show()
		BGS_CBHideTitle:SetChecked(true)
	else
		PlaySound("igMainMenuOptionCheckBoxOff");
		BGS_FrameTitle:Hide()
		BGS_CBHideTitle:SetChecked(false)
	end
	TrackFramePos()
	ResizeBG()
end)

----------------------------------------
-- Info Frame
----------------------------------------
local L_Text_Commands = CreateFrame("FRAME", "Text_Commands", BGS_Option)
local commandLines = {"|cFFFFD100BGStats commands:|r"
					,"|cFFFFD100/bgstats|r: Opens this options frame."
					,"|cFFFFD100/bgstats show|r: Shows the tracking frame."
					,"|cFFFFD100/bgstats hide|r: Hides the tracking frame."
					,"|cFFFFD100/bgstats lock|r: Toggle moveable tracking frame."}
for k, v in ipairs(commandLines) do
	local frame = _G["L_Text_Commands.text"..k]
	frame = L_Text_Commands:CreateFontString(nil, nil, FontCheckBox)
	frame:SetPoint("topleft", 0, -13 * (k-1))
	frame:SetText(v)
	frame:SetJustifyH("left")
	frame:SetJustifyV("middle")
	frame:SetHeight(15);
	frame:SetWidth(400);
end
	
L_Text_Commands:SetHeight(15*4);
L_Text_Commands:SetWidth(400);
L_Text_Commands:SetPoint("bottomleft", BGS_Option, "bottomleft", 15, 13*2)
L_Text_Commands:Show()

--[[
L_Text_Commands.text1 = L_Text_Commands:CreateFontString(nil, nil, FontCheckBox)
L_Text_Commands.text1:SetPoint("left", 0, 0)
L_Text_Commands.text1:SetText("|cFFFFD100BGStats commands:|r")
L_Text_Commands.text2 = L_Text_Commands:CreateFontString(nil, nil, FontCheckBox)
L_Text_Commands.text2:SetPoint("left", 0, -L_Text_Commands.text1:GetHeight())
L_Text_Commands.text2:SetText("|cFFFFD100/bgstats|r: Opens this options frame.")
L_Text_Commands.text3 = L_Text_Commands:CreateFontString(nil, nil, FontCheckBox)
L_Text_Commands.text3:SetPoint("left", 0, -L_Text_Commands.text1:GetHeight()*2)
L_Text_Commands.text3:SetText("|cFFFFD100/bgstats show|r: Shows the tracking frame.")
L_Text_Commands.text4 = L_Text_Commands:CreateFontString(nil, nil, FontCheckBox)
L_Text_Commands.text4:SetPoint("left", 0, -L_Text_Commands.text1:GetHeight()*3)
L_Text_Commands.text4:SetText("|cFFFFD100/bgstats hide|r: Hides the tracking frame.")
L_Text_Commands.text5 = L_Text_Commands:CreateFontString(nil, nil, FontCheckBox)
L_Text_Commands.text5:SetPoint("left", 0, -L_Text_Commands.text1:GetHeight()*4)
L_Text_Commands.text5:SetText("|cFFFFD100/bgstats lock|r: Toggle moveable tracking frame.")
]]--
------------------------------------------------------------------------------------------------------------------------


----------------------------------------
-- Updates
----------------------------------------

local function KillInfos()
   UpdateKillsInfo()
   UpdateAchInfo()
   UpdateAccKillsInfo()
end

------------------------------------------------------------------------------------------------------------------------

local function CurrInfos()
   UpdateConquestInfo()
   UpdateHonorInfo()
   UpdateTBInfo()
end

----------------------------------------
-- Event Frames
----------------------------------------

local L_BGS_KillEventFrame = CreateFrame("FRAME", "BGS_KillEventFrame");
BGS_KillEventFrame:RegisterEvent("PLAYER_PVP_KILLS_CHANGED");
BGS_KillEventFrame:SetScript("OnEvent", KillInfos);

------------------------------------------------------------------------------------------------------------------------

local L_BGS_ConquestEventFrame = CreateFrame("FRAME", "BGS_ConquestEventFrame");
BGS_ConquestEventFrame:RegisterEvent("CURRENCY_DISPLAY_UPDATE");
BGS_ConquestEventFrame:SetScript("OnEvent", CurrInfos);

------------------------------------------------------------------------------------------------------------------------

local L_BGS_ZoneEventFrame = CreateFrame("FRAME", "BGS_ZoneEventFrame");
BGS_ZoneEventFrame:RegisterEvent("PLAYER_ENTERING_BATTLEGROUND");
BGS_ZoneEventFrame:RegisterEvent("PLAYER_ENTERING_WORLD");
BGS_ZoneEventFrame:RegisterEvent("PLAYER_PVP_KILLS_CHANGED");
BGS_ZoneEventFrame:RegisterEvent("UPDATE_BATTLEFIELD_SCORE");
BGS_ZoneEventFrame:RegisterEvent("PLAYER_DEAD");
BGS_ZoneEventFrame:SetScript("OnEvent", UpdateBGScoreInfo);

------------------------------------------------------------------------------------------------------------------------
local function Firstrun()
	-- Add every frame
	for i=0, table.getn(DefaultFrames) do
		ShowFrame(i+1)
	end
	
	-- Movable
	SetShowMainframe(true)
	BGStatFrame:EnableMouse(true)
			
	BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON )
	BGStatFrame:SetBackdrop({
		bgFile = mainBGBack,
		edgeFile = [[Interface/DialogFrame/UI-DialogBox-Border]],
		tileSize = 0, edgeSize = 16,
		insets = { left = 3, right = 3, top = 3, bottom = 3 }
	})
			
	--Give default background
	ActiveBG = 2
	ChangeBG(ActiveBG)
	UIDropDownMenu_SetText(BGS_BGDropDown, ""..ActiveBG[1])
			
	--Show icons & title
	BGS_CBHideIcons:SetChecked(true)
	BGS_CBHideTitle:SetChecked(true)
end

local function CommonRun()

	local check = ShownFramesTable[1]
		if check ~= nil then
				
			if GetPositionInDefaultName(check) ~= -1 then
				for  id, frame in ipairs(ShownFramesTable) do
					local pos = GetPositionInDefaultName(frame)
					ShowFrame(pos)
				end
			else
				for i=0, table.getn(DefaultFrames) do
				ShowFrame(i+1)
			end
		end
	end

	SetShowMainframe(IsShown)

	if CanMove == false then
		BGStatFrame:EnableMouse(false)
		BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF )
		BGS_MoveButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF, DEFAULT_LOCKVERTEX_OFF )
	else
		BGStatFrame:EnableMouse(true)
		BGS_LockButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON )
		BGS_MoveButton.tex:SetVertexColor(DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON, DEFAULT_LOCKVERTEX_ON )
	end
	
	UpdateMainFrameBG()
	  
	ChangeBG(BackgroundId)
	  
	if TitleHidden ~= nil and TitleHidden == true then
		BGS_CBHideTitle:SetChecked(false)
		BGS_FrameTitle:Hide()
	else
		BGS_CBHideTitle:SetChecked(true)
		BGS_FrameTitle:Show()
	end
		
		
	if IconsHidden ~= nil and IconsHidden == true then
		BGS_CBHideIcons:SetChecked(false)
		for k, v in ipairs(IconFrames) do 
			v:Hide()
			v:GetParent().text:SetPoint("left", DEFAULT_TRACKOFFSET_WITHOUT, 0)
		end	
	else
		BGS_CBHideIcons:SetChecked(true)
		for k, v in ipairs(IconFrames) do 
			v:Show()
			v:GetParent().text:SetPoint("left", DEFAULT_TRACKOFFSET_WITH, 0)
		end
	end
end
	
local L_BGS_LoadFrame = CreateFrame("FRAME", "BGS_LoadFrame"); 
BGS_LoadFrame:RegisterEvent("ADDON_LOADED");
BGS_LoadFrame:RegisterEvent("PLAYER_LOGOUT");
BGS_LoadFrame:RegisterEvent("PLAYER_LOGIN");
BGS_LoadFrame:RegisterEvent("COMPACT_UNIT_FRAME_PROFILES_LOADED");
BGS_LoadFrame:SetScript("OnEvent", function(self, event, ...) self[event](self, ...) end)

function BGS_LoadFrame:COMPACT_UNIT_FRAME_PROFILES_LOADED(loadedAddon)
	if loadedAddon ~= addonName then return end
	self:UnregisterEvent("COMPACT_UNIT_FRAME_PROFILES_LOADED")
	
	InterfaceOptions_AddCategory(BGS_Option)

	
	self.COMPACT_UNIT_FRAME_PROFILES_LOADED = nil
end

function BGS_LoadFrame:ADDON_LOADED(loadedAddon)
	if loadedAddon ~= addonName then return end
	self:UnregisterEvent("ADDON_LOADED")
	for i=0, table.getn(DefaultFrames) do
		HideFrame(i+1)
	end
	if firstRun == false then --not first Time running 
		CommonRun()
	else
		Firstrun()
	end
	
	InterfaceOptions_AddCategory(BGS_Option)
	
	self.ADDON_LOADED = nil
end

function BGS_LoadFrame:PLAYER_LOGIN(loadedAddon)
	CurrInfos()
	KillInfos()
	UpdateHolidayInfo()
	ResizeBG()
    FrameHeights()
	FixOptionFrames()
	
end

function BGS_LoadFrame:PLAYER_LOGOUT(loadedAddon)
	local tempTable = {}
	for  id, list in ipairs(ShownFrames) do -- All frames that are currently shown 
		table.insert(tempTable, list[2]) -- Save framename
	end
	ShownFramesTable = tempTable
    
	if BGStatFrame:IsShown() == 1 then
		IsShown = true
	else
		IsShown = false
	end
	
	if BGStatFrame:IsMouseEnabled() == 1 then
		CanMove = true
	else
		CanMove = false
	end
	  
    firstRun = false
	  
	BackgroundId = ActiveBG
	  
	if BGS_CBHideTitle:GetChecked() == 1 then
		TitleHidden = false
	else
		TitleHidden = true
	end
	  
	if BGS_CBHideIcons:GetChecked() == 1 then
		IconsHidden = false
	else
		IconsHidden = true
	end
end


----------------------------------------
-- Slash Commands
----------------------------------------

SLASH_PVPSTATS1 = '/bgstats';
local function slashcmd(msg, editbox)
	if msg == 'hide' then
		SetShowMainframe(false)
	elseif msg == 'show' then
		SetShowMainframe(true)
	elseif msg == 'lock' then
		ToggleLockbutton()
	
	-- Debug
   --[[ 
   elseif msg == 'resize' then
   if debugMode then
      if ResizeBG() == true then
	  DEFAULT_CHAT_FRAME:AddMessage("|cFFFFAA00resized|r")
	  end
	end
	elseif msg == 'print' then
	 if debugMode then
      for  id, frame in ipairs(FrameTable) do -- All frames that are currently shown 
         local TempFrame = frame
         local TempFrameName = TempFrame:GetName()
         DEFAULT_CHAT_FRAME:AddMessage("".. TempFrameName)
	  end   
	end
	  
	  elseif msg == 'h' then
	 if debugMode then
			print( addonName)	
			print( addon)	
			print( val3)	
			print( val4)	
			print( val5)		
	
	end
	 ]]--
	else
		if ( not InterfaceOptionsFramePanelContainer.displayedPanel ) then
			InterfaceOptionsFrame_OpenToCategory(CONTROLS_LABEL);
		end
		InterfaceOptionsFrame_OpenToCategory(addonName) 
	  
   end
end
SlashCmdList["PVPSTATS"] = slashcmd